trace_ptb_summary

Function trace_ptb_summary 

pub fn trace_ptb_summary<Mode: ExecutionMode>(
    context: &mut ExecutionContext<'_, '_, '_>,
    trace_builder_opt: &mut Option<MoveTraceBuilder>,
    commands: &[Command],
) -> Result<(), ExecutionError>
Inserts PTB summary event into the trace. As is the case for all other public functions in this module, its body is (and must be) enclosed in an if statement checking if tracing is enabled.